@@ -10,6 +10,7 @@ from polars._utils.async_ import _AioDataFrameResult, _GeventDataFrameResult
 from polars._utils.deprecation import (
     deprecate_function,
     deprecate_renamed_parameter,
+    deprecate_streaming_parameter,
     issue_deprecation_warning,
 )
 from polars._utils.parse import (
@@ -20,6 +21,7 @@ from polars._utils.unstable import issue_unstable_warning, unstable
 from polars._utils.various import extend_bool
 from polars._utils.wrap import wrap_df, wrap_expr
 from polars.datatypes import DTYPE_TEMPORAL_UNITS, Date, Datetime, Int64
+from polars.lazyframe.opt_flags import OptFlags
 
 with contextlib.suppress(ImportError):  # Module not available when building docs
     import polars.polars as plr
@@ -31,6 +33,7 @@ if TYPE_CHECKING:
     from polars import DataFrame, Expr, LazyFrame, Series
     from polars._typing import (
         CorrelationMethod,
+        EngineType,
         EpochTimeUnit,
         IntoExpr,
         PolarsDataType,
@@ -789,7 +792,7 @@ def corr(
     propagate_nans: bool = False,
 ) -> Expr:
     """
-    Compute the Pearson's or Spearman rank correlation correlation between two columns.
+    Compute the Pearson's or Spearman rank correlation between two columns.
 
     Parameters
     ----------
@@ -1619,6 +1622,7 @@ def arg_sort_by(
     )
 
 
+@deprecate_streaming_parameter()
 def collect_all(
     lazy_frames: Iterable[LazyFrame],
     *,
@@ -1633,13 +1637,16 @@ def collect_all(
     comm_subexpr_elim: bool = True,
     cluster_with_columns: bool = True,
     collapse_joins: bool = True,
-    streaming: bool = False,
     _check_order: bool = True,
+    engine: EngineType = "auto",
 ) -> list[DataFrame]:
     """
     Collect multiple LazyFrames at the same time.
 
-    This runs all the computation graphs in parallel on the Polars threadpool.
+    This can run all the computation graphs in parallel or combined.
+
+    Common Subplan Elimination is applied on the combined plan, meaning
+    that diverging queries will run only once.
 
     Parameters
     ----------
@@ -1665,60 +1672,46 @@ def collect_all(
         Combine sequential independent calls to with_columns
     collapse_joins
         Collapse a join and filters into a faster join
-    streaming
-        Process the query in batches to handle larger-than-memory data.
-        If set to `False` (default), the entire query is processed in a single
-        batch.
-
-        .. warning::
-            Streaming mode is considered **unstable**. It may be changed
-            at any point without it being considered a breaking change.
+    engine
+        Select the engine used to process the query, optional.
+        At the moment, if set to `"auto"` (default), the query
+        is run using the polars in-memory engine. Polars will also
+        attempt to use the engine set by the `POLARS_ENGINE_AFFINITY`
+        environment variable. If it cannot run the query using the
+        selected engine, the query is run using the polars in-memory
+        engine.
 
         .. note::
-            Use :func:`explain` to see if Polars can process the query in streaming
-            mode.
+           The GPU engine does not support async, or running in the
+           background. If either are enabled, then GPU execution is switched off.
 
     Returns
     -------
     list of DataFrames
         The collected DataFrames, returned in the same order as the input LazyFrames.
+
     """
+    optflags = OptFlags(
+        _type_coercion=type_coercion,
+        _type_check=_type_check,
+        predicate_pushdown=predicate_pushdown,
+        projection_pushdown=projection_pushdown,
+        simplify_expression=simplify_expression,
+        slice_pushdown=slice_pushdown,
+        comm_subplan_elim=comm_subplan_elim,
+        comm_subexpr_elim=comm_subexpr_elim,
+        cluster_with_columns=cluster_with_columns,
+        collapse_joins=collapse_joins,
+        check_order_observe=_check_order,
+    )
     if no_optimization:
-        predicate_pushdown = False
-        projection_pushdown = False
-        slice_pushdown = False
-        comm_subplan_elim = False
-        comm_subexpr_elim = False
-        cluster_with_columns = False
-        collapse_joins = False
+        optflags.no_optimizations()
 
-    if streaming:
+    if engine in ("streaming", "old-streaming"):
         issue_unstable_warning("Streaming mode is considered unstable.")
-        comm_subplan_elim = False
 
-    prepared = []
-
-    for lf in lazy_frames:
-        type_check = _type_check
-        ldf = lf._ldf.optimization_toggle(
-            type_coercion=type_coercion,
-            type_check=type_check,
-            predicate_pushdown=predicate_pushdown,
-            projection_pushdown=projection_pushdown,
-            simplify_expression=simplify_expression,
-            slice_pushdown=slice_pushdown,
-            comm_subplan_elim=comm_subplan_elim,
-            comm_subexpr_elim=comm_subexpr_elim,
-            cluster_with_columns=cluster_with_columns,
-            collapse_joins=collapse_joins,
-            streaming=streaming,
-            _eager=False,
-            _check_order=_check_order,
-            new_streaming=False,
-        )
-        prepared.append(ldf)
-
-    out = plr.collect_all(prepared)
+    lfs = [lf._ldf for lf in lazy_frames]
+    out = plr.collect_all(lfs, engine, optflags._pyoptflags)
 
     # wrap the pydataframes into dataframe
     result = [wrap_df(pydf) for pydf in out]
@@ -1742,7 +1735,7 @@ def collect_all_async(
     comm_subexpr_elim: bool = True,
     cluster_with_columns: bool = True,
     collapse_joins: bool = True,
-    streaming: bool = True,
+    engine: EngineType = "auto",
 ) -> _GeventDataFrameResult[list[DataFrame]]: ...
 
 
@@ -1762,11 +1755,12 @@ def collect_all_async(
     comm_subexpr_elim: bool = True,
     cluster_with_columns: bool = True,
     collapse_joins: bool = True,
-    streaming: bool = False,
+    engine: EngineType = "auto",
 ) -> Awaitable[list[DataFrame]]: ...
 
 
 @unstable()
+@deprecate_streaming_parameter()
 def collect_all_async(
     lazy_frames: Iterable[LazyFrame],
     *,
@@ -1782,8 +1776,8 @@ def collect_all_async(
     comm_subexpr_elim: bool = True,
     cluster_with_columns: bool = True,
     collapse_joins: bool = True,
-    streaming: bool = False,
     _check_order: bool = True,
+    engine: EngineType = "auto",
 ) -> Awaitable[list[DataFrame]] | _GeventDataFrameResult[list[DataFrame]]:
     """
     Collect multiple LazyFrames at the same time asynchronously in thread pool.
@@ -1825,18 +1819,18 @@ def collect_all_async(
         Combine sequential independent calls to with_columns
     collapse_joins
         Collapse a join and filters into a faster join
-    streaming
-        Process the query in batches to handle larger-than-memory data.
-        If set to `False` (default), the entire query is processed in a single
-        batch.
-
-        .. warning::
-            Streaming mode is considered **unstable**. It may be changed
-            at any point without it being considered a breaking change.
+    engine
+        Select the engine used to process the query, optional.
+        At the moment, if set to `"auto"` (default), the query
+        is run using the polars in-memory engine. Polars will also
+        attempt to use the engine set by the `POLARS_ENGINE_AFFINITY`
+        environment variable. If it cannot run the query using the
+        selected engine, the query is run using the polars in-memory
+        engine.
 
         .. note::
-            Use :func:`explain` to see if Polars can process the query in streaming
-            mode.
+           The GPU engine does not support async, or running in the
+           background. If either are enabled, then GPU execution is switched off.
 
     See Also
     --------
@@ -1855,48 +1849,107 @@ def collect_all_async(
     If `gevent=True` then returns wrapper that has
     `.get(block=True, timeout=None)` method.
     """
+    optflags = OptFlags(
+        _type_coercion=type_coercion,
+        _type_check=_type_check,
+        predicate_pushdown=predicate_pushdown,
+        projection_pushdown=projection_pushdown,
+        simplify_expression=simplify_expression,
+        slice_pushdown=slice_pushdown,
+        comm_subplan_elim=comm_subplan_elim,
+        comm_subexpr_elim=comm_subexpr_elim,
+        cluster_with_columns=cluster_with_columns,
+        collapse_joins=collapse_joins,
+        check_order_observe=_check_order,
+    )
     if no_optimization:
-        predicate_pushdown = False
-        projection_pushdown = False
-        slice_pushdown = False
-        comm_subplan_elim = False
-        comm_subexpr_elim = False
-        cluster_with_columns = False
-        collapse_joins = False
+        optflags.no_optimizations()
 
-    if streaming:
+    if engine in ("streaming", "old-streaming"):
         issue_unstable_warning("Streaming mode is considered unstable.")
-        comm_subplan_elim = False
-
-    prepared = []
-
-    for lf in lazy_frames:
-        type_check = _type_check
-        ldf = lf._ldf.optimization_toggle(
-            type_coercion=type_coercion,
-            type_check=type_check,
-            predicate_pushdown=predicate_pushdown,
-            projection_pushdown=projection_pushdown,
-            simplify_expression=simplify_expression,
-            slice_pushdown=slice_pushdown,
-            comm_subplan_elim=comm_subplan_elim,
-            comm_subexpr_elim=comm_subexpr_elim,
-            cluster_with_columns=cluster_with_columns,
-            collapse_joins=collapse_joins,
-            streaming=streaming,
-            _eager=False,
-            _check_order=_check_order,
-            new_streaming=False,
-        )
-        prepared.append(ldf)
 
     result: (
         _GeventDataFrameResult[list[DataFrame]] | _AioDataFrameResult[list[DataFrame]]
     ) = _GeventDataFrameResult() if gevent else _AioDataFrameResult()
-    plr.collect_all_with_callback(prepared, result._callback_all)
+    lfs = [lf._ldf for lf in lazy_frames]
+    plr.collect_all_with_callback(
+        lfs, engine, optflags._pyoptflags, result._callback_all
+    )
     return result
 
 
+@unstable()
+def explain_all(
+    lazy_frames: Iterable[LazyFrame],
+    *,
+    type_coercion: bool = True,
+    _type_check: bool = True,
+    predicate_pushdown: bool = True,
+    projection_pushdown: bool = True,
+    simplify_expression: bool = True,
+    no_optimization: bool = False,
+    slice_pushdown: bool = True,
+    comm_subplan_elim: bool = True,
+    comm_subexpr_elim: bool = True,
+    cluster_with_columns: bool = True,
+    collapse_joins: bool = True,
+    _check_order: bool = True,
+) -> str:
+    """
+    Explain multiple LazyFrames as if passed to `collect_all`.
+
+    Common Subplan Elimination is applied on the combined plan, meaning
+    that diverging queries will run only once.
+
+    Parameters
+    ----------
+    lazy_frames
+        A list of LazyFrames to collect.
+    type_coercion
+        Do type coercion optimization.
+    predicate_pushdown
+        Do predicate pushdown optimization.
+    projection_pushdown
+        Do projection pushdown optimization.
+    simplify_expression
+        Run simplify expressions optimization.
+    no_optimization
+        Turn off optimizations.
+    slice_pushdown
+        Slice pushdown optimization.
+    comm_subplan_elim
+        Will try to cache branching subplans that occur on self-joins or unions.
+    comm_subexpr_elim
+        Common subexpressions will be cached and reused.
+    cluster_with_columns
+        Combine sequential independent calls to with_columns
+    collapse_joins
+        Collapse a join and filters into a faster join
+
+    Returns
+    -------
+    Explained plan.
+    """
+    optflags = OptFlags(
+        _type_coercion=type_coercion,
+        _type_check=_type_check,
+        predicate_pushdown=predicate_pushdown,
+        projection_pushdown=projection_pushdown,
+        simplify_expression=simplify_expression,
+        slice_pushdown=slice_pushdown,
+        comm_subplan_elim=comm_subplan_elim,
+        comm_subexpr_elim=comm_subexpr_elim,
+        cluster_with_columns=cluster_with_columns,
+        collapse_joins=collapse_joins,
+        check_order_observe=_check_order,
+    )
+    if no_optimization:
+        optflags.no_optimizations()
+
+    lfs = [lf._ldf for lf in lazy_frames]
+    return plr.explain_all(lfs, optflags._pyoptflags)
+
+
 @overload
 def select(
     *exprs: IntoExpr | Iterable[IntoExpr],
